# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

accessToken: Optional[str]
"""
Access token for Venafi TLSPDC, user should use this for authentication
"""

apiKey: Optional[str]
"""
API key for Venafi Control Plane. Example: 142231b7-cvb0-412e-886b-6aeght0bc93d
"""

clientId: Optional[str]
"""
application that will be using the token
"""

devMode: Optional[bool]
"""
When set to true, the resulting certificate will be issued by an ephemeral, no trust CA rather than enrolling using Venafi as a Service or Trust Protection Platform. Useful for development and testing
"""

externalJwt: Optional[str]
"""
JWT of the identity provider associated to the Venafi Control Plane service account that is granting the access token
"""

p12CertData: Optional[str]
"""
Base64 encoded PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
"""

p12CertFilename: Optional[str]
"""
Filename of PKCS#12 keystore containing a client certificate, private key, and chain certificates to authenticate to TLSPDC
"""

p12CertPassword: Optional[str]
"""
Password for the PKCS#12 keystore declared in p12_cert / p12_cert_data
"""

skipRetirement: Optional[bool]

tokenUrl: Optional[str]
"""
Endpoint URL to request new Venafi Control Plane access tokens
"""

tppPassword: Optional[str]
"""
Password for WebSDK user. Example: password
"""

tppUsername: Optional[str]
"""
WebSDK user for Venafi TLSPDC. Example: admin
"""

trustBundle: Optional[str]
"""
Use to specify a PEM-formatted file that contains certificates to be trust anchors for all communications with the Venafi Web Service.
Example:
  trust_bundle = "${file("chain.pem")}"
"""

url: Optional[str]
"""
The Venafi Platform URL. Example: https://tpp.venafi.example/vedsdk
"""

zone: Optional[str]
"""
DN of the Venafi TLSPDC policy folder or name of the Venafi as a Service application plus issuing template alias. 
Example for Platform: testPolicy\\\\vault
Example for Venafi as a Service: myApp\\\\Default
"""

